"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var core_1 = require('@angular/core');
var Observable_1 = require('rxjs/Observable');
var BehaviorSubject_1 = require('rxjs/BehaviorSubject');
require('rxjs/add/observable/fromEvent');
require('rxjs/add/operator/map');
require('rxjs/add/operator/filter');
require('rxjs/add/operator/distinctUntilChanged');
var defaultBreakpoints = {
    xs: { max: 768 },
    sm: { min: 768, max: 992 },
    md: { min: 992, max: 1200 },
    lg: { min: 1200 }
};
var FALLBACK_BREAKPOINT = {
    min: 0, max: Number.MAX_SAFE_INTEGER
};
exports.breakpointsProvider = function (breakpoints) {
    return core_1.provide(BreakpointsService, {
        useFactory: function (ngZone) {
            return new BreakpointsService(ngZone, breakpoints);
        },
        deps: [core_1.NgZone]
    });
};
var BreakpointsService = (function () {
    function BreakpointsService(ngZone, breakpoints) {
        this.ngZone = ngZone;
        this.breakpoints = defaultBreakpoints;
        this.setBreakpoints(breakpoints);
        this.resize = Observable_1.Observable.fromEvent(window, 'resize').map(this.getWindowSize).distinctUntilChanged();
        var initialBreakpoint = this.getBreakpoint(window.innerWidth);
        this.changesSubject = new BehaviorSubject_1.BehaviorSubject(this.getBreakpointEvent(initialBreakpoint));
        this.changes = this.changesSubject.distinctUntilChanged(function (x, y) { return x.name === y.name; });
        this.subscribe();
    }
    // Unsubscribe to the resize event
    BreakpointsService.prototype.unsubscribe = function () {
        if (this.subscription) {
            this.subscription.unsubscribe();
            this.subscription = null;
        }
    };
    // Subscribe to the resize event
    BreakpointsService.prototype.subscribe = function () {
        var _this = this;
        if (this.subscription) {
            return;
        }
        this.subscription = this.resize.subscribe(function (size) {
            var breakpoint = _this.getBreakpoint(size.width);
            if (core_1.NgZone.isInAngularZone()) {
                _this.changesSubject.next(_this.getBreakpointEvent(breakpoint));
            }
            else {
                // NgZone doesnt listen to resize window event, so we have to run this in NgZone to run change detection
                _this.ngZone.run(function () {
                    _this.changesSubject.next(_this.getBreakpointEvent(breakpoint));
                });
            }
        });
    };
    // Sets the customized breakpoints
    BreakpointsService.prototype.setBreakpoints = function (breakpoints) {
        if (breakpoints) {
            this.breakpoints = breakpoints;
        }
    };
    // Returns a breakpoint event, with the fallback breakpoint if none were found
    BreakpointsService.prototype.getBreakpointEvent = function (name) {
        if (!name) {
            return { name: 'default', breakpoint: FALLBACK_BREAKPOINT, size: this.getWindowSize() };
        }
        else {
            return { name: name, breakpoint: this.breakpoints[name], size: this.getWindowSize() };
        }
    };
    // Returns the current window size
    BreakpointsService.prototype.getWindowSize = function () {
        return { width: window.innerWidth, height: window.innerHeight };
    };
    // Returns the first breakpoint that match the current size
    BreakpointsService.prototype.getBreakpoint = function (currentSize) {
        var keys = Object.keys(this.breakpoints);
        for (var _i = 0, keys_1 = keys; _i < keys_1.length; _i++) {
            var key = keys_1[_i];
            var value = this.breakpoints[key];
            var min = value.min || 0;
            var max = value.max || Number.MAX_SAFE_INTEGER;
            if (currentSize >= min && currentSize < max) {
                return key;
            }
        }
        return null;
    };
    BreakpointsService = __decorate([
        core_1.Injectable(), 
        __metadata('design:paramtypes', [Object, Object])
    ], BreakpointsService);
    return BreakpointsService;
}());
exports.BreakpointsService = BreakpointsService;
//# sourceMappingURL=index.js.map